BtcAdapterState enum Enums

State of the Bluetooth adapter.

State Description
unknown Adapter state cannot be determined
turningOn Adapter is transitioning to the on state
on Adapter is powered on and ready
turningOff Adapter is transitioning to the off state
off Adapter is powered off
unauthorized App lacks permission to access Bluetooth
unsupported Device does not have Bluetooth hardware
Inheritance
Available extensions

Values

unknown → const BtcAdapterState

Adapter state cannot be determined.

turningOn → const BtcAdapterState

Adapter is transitioning to the on state.

on → const BtcAdapterState

Adapter is powered on and ready.

turningOff → const BtcAdapterState

Adapter is transitioning to the off state.

off → const BtcAdapterState

Adapter is powered off.

unauthorized → const BtcAdapterState

App lacks permission to access Bluetooth.

unsupported → const BtcAdapterState

Device does not have Bluetooth hardware.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BtcAdapterState>
A constant List of the values in this enum, in order of their declaration.