BtcAddressException class Exceptions

Thrown when an invalid Bluetooth MAC address is provided.

Inheritance

Constructors

BtcAddressException(String address)
Creates a BtcAddressException for the invalid address.
const

Properties

address String
The invalid address that was provided.
final
code String?
Optional error code from the native platform.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String
Human-readable error message.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited