BtcDisabledException class Exceptions

Thrown when an operation requires Bluetooth to be enabled but it is off.

Inheritance

Constructors

BtcDisabledException([String message = 'Bluetooth adapter is disabled'])
Creates a BtcDisabledException with an optional message.
const

Properties

code → String?
Optional error code from the native platform.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
message → String
Human-readable error message.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited