BtcDiscoveryException class Exceptions

Thrown when starting or running device discovery fails.

Inheritance

Constructors

BtcDiscoveryException([String message = 'Failed to start discovery'])
Creates a BtcDiscoveryException with an optional message.
const

Properties

code String?
Optional error code from the native platform.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String
Human-readable error message.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited