BtcUuidException class Exceptions

Thrown when an invalid UUID is provided.

Inheritance

Constructors

BtcUuidException(String uuid)
Creates a BtcUuidException for the invalid uuid.
const

Properties

code String?
Optional error code from the native platform.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String
Human-readable error message.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uuid String
The invalid UUID that was provided.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited