BtcDisabledException class Exceptions
Thrown when an operation requires Bluetooth to be enabled but it is off.
- Inheritance
-
- Object
- BtcException
- BtcDisabledException
Constructors
- BtcDisabledException([String message = 'Bluetooth adapter is disabled'])
-
Creates a BtcDisabledException with an optional
message.const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited