BtcTimeoutException class Exceptions
Thrown when an operation times out.
- Inheritance
-
- Object
- BtcException
- BtcTimeoutException
Constructors
- BtcTimeoutException({String message = 'Operation timed out', int? timeoutMs})
-
Creates a BtcTimeoutException with an optional
messageand the elapsedtimeoutMs.const
Properties
- code → String?
-
Optional error code from the native platform.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Human-readable error message.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeoutMs → int?
-
The duration in milliseconds that elapsed before timeout.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited