BtcWriteException class Exceptions
Thrown when a write operation to a connected device fails.
- Inheritance
-
- Object
- BtcException
- BtcWriteException
Constructors
- BtcWriteException([String message = 'Failed to write data'])
-
Creates a BtcWriteException with an optional
message.const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited